# -*- coding: utf-8 -*-

FROM php:8.1.18-fpm-alpine3.17

LABEL authors="Nicolas Béjean <nicolas@bejean.fr>"
LABEL company="Béjean Développement"
LABEL website="www.bejean.eu"
LABEL version="1.0"

# Addgroup and adduser
RUN addgroup -g 1000 app \
  && adduser -D -H -h /var/www -s /sbin/nologin -G app -u 1000 app

# Change listen parameter
RUN sed -i 's/^listen = 127.0.0.1:9000*/listen = 9000/' /usr/local/etc/php-fpm.d/www.conf

# Change user and group www-data to app
RUN sed -i 's/^user = www-data*/user = app/' /usr/local/etc/php-fpm.d/www.conf
RUN sed -i 's/^group = www-data*/group = app/' /usr/local/etc/php-fpm.d/www.conf
RUN sed -i 's/^;listen.owner = www-data*/listen.owner = app/' /usr/local/etc/php-fpm.d/www.conf
RUN sed -i 's/^;listen.group = www-data*/listen.group = app/' /usr/local/etc/php-fpm.d/www.conf

# Set timezone
ENV TZ=Europe/Paris
RUN ln -snf /usr/share/zoneinfo/$TZ /etc/localtime && echo $TZ > /etc/timezone

# Create directories and upate permissions
RUN mkdir -p /var/www/html /sock /var/log/php \
  && chown -R app:app /var/www /usr/local/etc /sock /var/log/php

# Change owner and group
USER app:app

# Change workdir
WORKDIR /var/www/html

# Expose port 9000
EXPOSE 9000
